"""
Built-in style package.

This package contains JSON files defining a selection of default styles.
Additional styles can be added by dropping a `*.json` file into this directory.
Each file must contain a mapping compatible with the
`q_materialise.style.Style` constructor.

Note:
    You should not import anything from this module directly. Instead, use
    `q_materialise.list_styles` and `q_materialise.get_style` to discover and
    load styles.
"""
